Web   ·   Wiki   ·   Activities   ·   Blog   ·   Lists   ·   Chat   ·   Meeting   ·   Bugs   ·   Git   ·   Translate   ·   Archive   ·   People   ·   Donate
summaryrefslogtreecommitdiffstats
path: root/pdf/goo/GString.h
diff options
context:
space:
mode:
Diffstat (limited to 'pdf/goo/GString.h')
-rw-r--r--pdf/goo/GString.h19
1 files changed, 11 insertions, 8 deletions
diff --git a/pdf/goo/GString.h b/pdf/goo/GString.h
index 4c3b95f..93796cb 100644
--- a/pdf/goo/GString.h
+++ b/pdf/goo/GString.h
@@ -4,7 +4,7 @@
//
// Simple variable-length string type.
//
-// Copyright 1996 Derek B. Noonburg
+// Copyright 1996-2002 Glyph & Cog, LLC
//
//========================================================================
@@ -24,11 +24,14 @@ public:
GString();
// Create a string from a C string.
- GString(const char *s1);
+ GString(const char *sA);
- // Create a string from <length1> chars at <s1>. This string
+ // Create a string from <lengthA> chars at <sA>. This string
// can contain null characters.
- GString (const char *s1, int length1);
+ GString(const char *sA, int lengthA);
+
+ // Create a string from <lengthA> chars at <idx> in <str>.
+ GString(GString *str, int idx, int lengthA);
// Copy a string.
GString(GString *str);
@@ -62,13 +65,13 @@ public:
GString *append(char c);
GString *append(GString *str);
GString *append(const char *str);
- GString *append(const char *str, int length1);
+ GString *append(const char *str, int lengthA);
// Insert a character or string.
GString *insert(int i, char c);
GString *insert(int i, GString *str);
GString *insert(int i, const char *str);
- GString *insert(int i, const char *str, int length1);
+ GString *insert(int i, const char *str, int lengthA);
// Delete a character or range of characters.
GString *del(int i, int n = 1);
@@ -81,8 +84,8 @@ public:
// These functions assume the strings do not contain null characters.
int cmp(GString *str) { return strcmp(s, str->getCString()); }
int cmpN(GString *str, int n) { return strncmp(s, str->getCString(), n); }
- int cmp(const char *s1) { return strcmp(s, s1); }
- int cmpN(const char *s1, int n) { return strncmp(s, s1, n); }
+ int cmp(const char *sA) { return strcmp(s, sA); }
+ int cmpN(const char *sA, int n) { return strncmp(s, sA, n); }
private: